@@ -223,7 +223,7 @@
 //!
 //! ```toml
 //! [dependencies]
-//! revai = "0.2.2"
+//! revai = "0.2.3"
 //! ```
 //!
 //! ## Basic example
@@ -251,7 +251,6 @@
 //!
 //! let rev.ai = Client::new_from_env();
 //! ```
-#![feature(async_stream)]
 #![allow(clippy::too_many_arguments)]
 #![allow(clippy::nonstandard_macro_braces)]
 #![allow(clippy::large_enum_variant)]
@@ -302,7 +301,7 @@ pub struct Client {
     host: String,
     token: String,
 
-    client: reqwest::Client,
+    client: reqwest_middleware::ClientWithMiddleware,
 }
 
 impl Client {
@@ -314,13 +313,26 @@ impl Client {
         T: ToString,
     {
         let client = reqwest::Client::builder().build();
+        let retry_policy =
+            reqwest_retry::policies::ExponentialBackoff::builder().build_with_max_retries(3);
         match client {
-            Ok(c) => Client {
-                host: DEFAULT_HOST.to_string(),
-                token: token.to_string(),
+            Ok(c) => {
+                let client = reqwest_middleware::ClientBuilder::new(c)
+                    // Trace HTTP requests. See the tracing crate to make use of these traces.
+                    .with(reqwest_tracing::TracingMiddleware)
+                    // Retry failed requests.
+                    .with(reqwest_retry::RetryTransientMiddleware::new_with_policy(
+                        retry_policy,
+                    ))
+                    .build();
 
-                client: c,
-            },
+                Client {
+                    host: DEFAULT_HOST.to_string(),
+                    token: token.to_string(),
+
+                    client,
+                }
+            }
             Err(e) => panic!("creating reqwest client failed: {:?}", e),
         }
     }
@@ -392,7 +404,6 @@ impl Client {
             );
             req = req.body(body);
         }
-        log::debug!("request: {:?}", &req);
         Ok(req.send().await?)
     }
 
@@ -521,7 +532,6 @@ impl Client {
         log::debug!("form: {:?}", form);
         req = req.multipart(form);
 
-        log::debug!("request: {:?}", &req);
         let response = req.send().await?;
 
         let status = response.status();
@@ -593,7 +603,6 @@ impl Client {
             req = req.header(http::header::AUTHORIZATION, &*auth_str);
         }
 
-        log::debug!("request: {:?}", &req);
         let response = req.send().await?;
 
         let status = response.status();
@@ -686,7 +695,6 @@ impl Client {
             req = req.body(b);
         }
 
-        log::debug!("request: {:?}", &req);
         let response = req.send().await?;
 
         let status = response.status();
